==> haskell-regex-applicative-text-0.1.0.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative-text
version: 0.1.0.1
id: regex-applicative-text-0.1.0.1-Id6MEO698SW3W0izxZ7hIu
key: regex-applicative-text-0.1.0.1-Id6MEO698SW3W0izxZ7hIu
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/regex-applicative-text#readme
synopsis: regex-applicative on text
description:
    Wrapped regex-applicative primitives to work with Text
category: Text
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.Applicative.Text
abi: eb743be53d107e830348994926d46c36
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-applicative-text-0.1.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-applicative-text-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/regex-applicative-text-0.1.0.1
hs-libraries: HSregex-applicative-text-0.1.0.1-Id6MEO698SW3W0izxZ7hIu
depends:
    base-4.10.1.0 regex-applicative-0.3.3-DxcXiGFOKNJAEyOISHX5JB
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             regex-applicative-0.3.3-DxcXiGFOKNJAEyOISHX5JB=122463352fd3d35c41b65641e1bba1e1
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-text-0.1.0.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative-text
version: 0.1.0.1
id: regex-applicative-text-0.1.0.1-HaQE8rRZ3CC89PcIMyh2mu
key: regex-applicative-text-0.1.0.1-HaQE8rRZ3CC89PcIMyh2mu
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/regex-applicative-text#readme
synopsis: regex-applicative on text
description:
    Wrapped regex-applicative primitives to work with Text
category: Text
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.Applicative.Text
abi: d05f4aa76bca4cb1e8af864b3f3bdbf0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-applicative-text-0.1.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-applicative-text-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/regex-applicative-text-0.1.0.1
hs-libraries: HSregex-applicative-text-0.1.0.1-HaQE8rRZ3CC89PcIMyh2mu
depends:
    base-4.10.1.0 regex-applicative-0.3.3-DxcXiGFOKNJAEyOISHX5JB
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             regex-applicative-0.3.3-DxcXiGFOKNJAEyOISHX5JB=122463352fd3d35c41b65641e1bba1e1
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
